==> libcli-0.0.4.tar.gz: test/command_service_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'mock/dto/sample/echo_action.pbserver.dart';
import 'mock/dto/sample/string_response.pbserver.dart';
import 'mock/dto/sample/sample_service.pb.dart';

void main() {
  SampleService service = SampleService();
  group('Command Service', () {
    test('should encode ProtoObject', () {
      EchoAction echoAction = EchoAction();
      echoAction.text = 'helloWorld';
      List<int> list = service.encode(echoAction);
      expect(list.length, 14);
    });

    test('should decode ProtoObject', () {
      EchoAction echoAction = EchoAction();
      echoAction.text = 'helloWorld';
      List<int> list = service.encode(echoAction);
      EchoAction decodeAction = service.decode(list);
      expect(decodeAction.text, 'helloWorld');
    });

    test('should decode fail when id is wrong', () {
      EchoAction echoAction = EchoAction();
      echoAction.text = 'helloWorld';
      List<int> list = service.encode(echoAction);
      list[list.length - 1] = 255;
      try {
        service.decode(list);
        expect(1, 0); // this line should be execute
      } on Exception catch (e) {
        expect(e != null, true);
      }
    });

/*
    test('should do http post', () async {
      DioMock mock = DioMock();
      List<int> listRespond = List<int>();
      listRespond.add(2);
      mock.binaryResponse = listRespond;
      CommandService mockService = CommandService('http://localhost', null);
      mockService.setMockHttpAdapter(mock);

      Uint8List listPost = Uint8List.fromList(new List());
      List<int> response = await mockService.post(listPost);
      expect(response[0], 2);
    });
*/
    test('should provide fake mockResponse', () {
      SampleService fakeService = SampleService();
      StringResponse r = StringResponse();
      r.text = "fake";
      fakeService.mockResponse = r;

      EchoAction echoAction = new EchoAction();
      echoAction.text = 'helloWorld';
      fakeService.execute(echoAction).listen(expectAsync1((result) {
        StringResponse r2 = result;
        expect(r2.text, "fake");
      }));
    });

    test('should respond by fake mockResponder', () {
      SampleService fakeService = SampleService();
      fakeService.mockResponder = (cmd) {
        var r = StringResponse();
        r.text = "fake";
        return r;
      };

      EchoAction echoAction = new EchoAction();
      echoAction.text = 'hi';
      fakeService.execute(echoAction).listen(expectAsync1((result) {
        var response = result as StringResponse;
        expect(response.text, "fake");
      }));
    });

    test('should throw exception when url is wrong', () {
      SampleService noService = SampleService();
      noService.timeout = 1; // set 1 ms to fail
      EchoAction echoAction = new EchoAction();
      echoAction.text = 'helloWorld';
      noService.execute(echoAction).listen(
          (result) {
            expect(1, 0); // should not run to here
          },
          onDone: () {},
          onError: expectAsync1((err) {
            expect(err != null, true);
          }),
          cancelOnError: true);
    });
  });
}

==> libcli-0.0.5.tar.gz: test/command_service_test.dart <==
import 'package:flutter_test/flutter_test.dart';
import 'mock/dto/sample/echo_action.pbserver.dart';
import 'mock/dto/sample/string_response.pbserver.dart';
import 'mock/dto/sample/sample_service.pb.dart';

void main() {
  SampleService service = SampleService();
  group('Command Service', () {
    test('should encode ProtoObject', () {
      EchoAction echoAction = EchoAction();
      echoAction.text = 'helloWorld';
      List<int> list = service.encode(echoAction);
      expect(list.length, 14);
    });

    test('should decode ProtoObject', () {
      EchoAction echoAction = EchoAction();
      echoAction.text = 'helloWorld';
      List<int> list = service.encode(echoAction);
      EchoAction decodeAction = service.decode(list);
      expect(decodeAction.text, 'helloWorld');
    });

    test('should decode fail when id is wrong', () {
      EchoAction echoAction = EchoAction();
      echoAction.text = 'helloWorld';
      List<int> list = service.encode(echoAction);
      list[list.length - 1] = 255;
      try {
        service.decode(list);
        expect(1, 0); // this line should not be execute
      } on Exception catch (e) {
        expect(e != null, true);
      }
    });

/*
    test('should do http post', () async {
      DioMock mock = DioMock();
      List<int> listRespond = List<int>();
      listRespond.add(2);
      mock.binaryResponse = listRespond;
      CommandService mockService = CommandService('http://localhost', null);
      mockService.setMockHttpAdapter(mock);

      Uint8List listPost = Uint8List.fromList(new List());
      List<int> response = await mockService.post(listPost);
      expect(response[0], 2);
    });
*/
    test('should provide fake mockResponse', () {
      SampleService fakeService = SampleService();
      StringResponse r = StringResponse();
      r.text = "fake";
      fakeService.mockResponse = r;

      EchoAction echoAction = new EchoAction();
      echoAction.text = 'helloWorld';
      fakeService.execute(echoAction).listen(expectAsync1((result) {
        StringResponse r2 = result;
        expect(r2.text, "fake");
      }));
    });

    test('should respond by fake mockResponder', () {
      SampleService fakeService = SampleService();
      fakeService.mockResponder = (cmd) {
        var r = StringResponse();
        r.text = "fake";
        return r;
      };

      EchoAction echoAction = new EchoAction();
      echoAction.text = 'hi';
      fakeService.execute(echoAction).listen(expectAsync1((result) {
        var response = result as StringResponse;
        expect(response.text, "fake");
      }));
    });

    test('should throw exception when url is wrong', () {
      SampleService noService = SampleService();
      noService.timeout = 1; // set 1 ms to fail
      EchoAction echoAction = new EchoAction();
      echoAction.text = 'helloWorld';
      noService.execute(echoAction).listen(
          (result) {
            expect(1, 0); // should not run to here
          },
          onDone: () {},
          onError: expectAsync1((err) {
            expect(err != null, true);
          }),
          cancelOnError: true);
    });
  });
}
